==> qmmp-0.4.1.tar.bz2: qmmp-0.4.1/src/plugins/Output/alsa/translations/alsa_plugin_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_CN">
<context>
    <name>OutputALSAFactory</name>
    <message>
        <location filename="../outputalsafactory.cpp" line="31"/>
        <source>ALSA Plugin</source>
        <translation>ALSA 插件</translation>
    </message>
    <message>
        <location filename="../outputalsafactory.cpp" line="56"/>
        <source>About ALSA Output Plugin</source>
        <translation>关于 ALSA 输出插件</translation>
    </message>
    <message>
        <location filename="../outputalsafactory.cpp" line="57"/>
        <source>Qmmp ALSA Output Plugin</source>
        <translation>Qmmp ALSA 输出插件</translation>
    </message>
    <message>
        <location filename="../outputalsafactory.cpp" line="58"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>作者：Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="33"/>
        <source>Device Settings</source>
        <translation>设备设置</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="45"/>
        <source>Audio device</source>
        <translation>音频设备</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="57"/>
        <source>Mixer</source>
        <translation>混频</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="72"/>
        <source>Mixer card:</source>
        <translation>混频卡：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="82"/>
        <source>Mixer device:</source>
        <translation>混频设备：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="99"/>
        <source>Advanced Settings</source>
        <translation>高级设置</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="111"/>
        <source>Soundcard</source>
        <translation>声卡</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="117"/>
        <source>Buffer time (ms):</source>
        <translation>缓冲时间(ms)：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="153"/>
        <source>Period time (ms):</source>
        <translation>周期时间(ms)：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="209"/>
        <source>Use snd_pcm_pause function</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>ALSA Plugin Settings</source>
        <translation>ALSA 插件设置</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="189"/>
        <source>Use mmap access</source>
        <translation>使用内存映射</translation>
    </message>
</context>
</TS>

==> qmmp-0.4.5.tar.bz2: qmmp-0.4.5/src/plugins/Output/alsa/translations/alsa_plugin_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_CN">
<context>
    <name>OutputALSAFactory</name>
    <message>
        <location filename="../outputalsafactory.cpp" line="31"/>
        <source>ALSA Plugin</source>
        <translation>ALSA 插件</translation>
    </message>
    <message>
        <location filename="../outputalsafactory.cpp" line="56"/>
        <source>About ALSA Output Plugin</source>
        <translation>关于 ALSA 输出插件</translation>
    </message>
    <message>
        <location filename="../outputalsafactory.cpp" line="57"/>
        <source>Qmmp ALSA Output Plugin</source>
        <translation>Qmmp ALSA 输出插件</translation>
    </message>
    <message>
        <location filename="../outputalsafactory.cpp" line="58"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>作者：Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="33"/>
        <source>Device Settings</source>
        <translation>设备设置</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="45"/>
        <source>Audio device</source>
        <translation>音频设备</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="57"/>
        <source>Mixer</source>
        <translation>混频</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="72"/>
        <source>Mixer card:</source>
        <translation>混频卡：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="82"/>
        <source>Mixer device:</source>
        <translation>混频设备：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="99"/>
        <source>Advanced Settings</source>
        <translation>高级设置</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="111"/>
        <source>Soundcard</source>
        <translation>声卡</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="117"/>
        <source>Buffer time (ms):</source>
        <translation>缓冲时间(ms)：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="153"/>
        <source>Period time (ms):</source>
        <translation>周期时间(ms)：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="209"/>
        <source>Use snd_pcm_pause function</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>ALSA Plugin Settings</source>
        <translation>ALSA 插件设置</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="189"/>
        <source>Use mmap access</source>
        <translation>使用内存映射</translation>
    </message>
</context>
</TS>
